
Contributors
============

- Jonathan Underwood combined the block and frame modules into a coherent single
  project with many fixes, clean-ups and documentation
- Jonathan Underwood added frame bindings based on the `lz4ex
  <https://github.com/jerryryle/python-lz4ex>`_ by Jerry Ryle and the `lz4tools
  <https://github.com/darkdragn/lz4tools>`_ project by Christopher Jackson
- Jonathan Underwood updated the block format support to use the tunable
  accelerated and high compression functions
- Mathew Rocklin added support for dropping the GIL to the block
  module, and Travis testing support
- Antoine Martin added initial support for fast compression support to
  the block library
- Steve Morin wrote the original lz4 block bindings

